# tristan

A set of prototype data processing tools for Tristan, the experimental [Timepix3-based](https://doi.org/10.1016/j.nima.2016.04.075) event-mode X-ray detector at Diamond Light Source.

See [the `tristan` ReadTheDocs
page](https://tristan.readthedocs.io/en/latest/usage.html) for more info on
usage of these tools.

All the command-line utilities in this package provide help for the various
commands and sub-commands with `<command> --help`.
